"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.LibSqlConnection = void 0;
const node_path_1 = require("node:path");
const knex_1 = require("@mikro-orm/knex");
const fs_extra_1 = require("fs-extra");
class LibSqlConnection extends knex_1.BaseSqliteConnection {
    async connect() {
        this.createKnex();
        const dbName = this.config.get('dbName');
        if (dbName && dbName !== ':memory:' && !(0, node_path_1.dirname)(dbName).startsWith('libsql:/')) {
            await (0, fs_extra_1.ensureDir)((0, node_path_1.dirname)(dbName));
        }
        await this.client.raw('pragma foreign_keys = on');
    }
    createKnex() {
        this.client = this.createKnexClient(knex_1.LibSqlKnexDialect);
        this.connected = true;
    }
    getKnexOptions(type) {
        return knex_1.Utils.mergeConfig({
            client: type,
            connection: {
                filename: this.config.get('dbName'),
                authToken: this.config.get('password'),
            },
            pool: this.config.get('pool'),
            useNullAsDefault: true,
        }, this.config.get('driverOptions'));
    }
}
exports.LibSqlConnection = LibSqlConnection;
